@@ -1,8 +1,9 @@
-from .b64 import Base64Service  # noqa
+from .b64 import Base64Service  # noqa: F401
 from .unicode import UnicodeService
 from .qrcode import QRCodeService
 from .barcode import BarCodeService
-from .mod import ModService  # noqa
+from .mod import ModService  # noqa: F401
+from .febrabran import FebrabranService  # noqa: F401
 
 
 parse_unicode_to_alphanumeric = UnicodeService().parse_unicode_to_alphanumeric
